#!BPY

"""
Name: 'Custom properties (.txt)'
Blender: 249
Group: 'Export'
Tooltip: 'Export all object properties to a single file'
"""

__author__ = "Sirius"

__bpydoc__ = """\
This script will export all custom object properties to a single file.
Example output:

hello:
    type: region
Cube:
    type: region
    page_num: 666
"""


import Blender, bpy
from Blender import Mesh, Scene, Window, sys, Image, Draw, Object
import BPyMesh
import BPyObject
import BPySys
import BPyMessages

def export_properties(filename):
    f=open(filename, "w")
    
    for obj in bpy.data.objects:
        f.write("\n")
        f.write("%s:\n" % obj.getName())
        for prop in obj.getAllProperties():
            f.write("\t%s: %s\n" % (prop.getName(), prop.getData()))
        
        dynamic = False
        actor = False
        collisions = False
        collisionstype = "box"
        mass = 0
        HullTypes = {"BOX" : 0, "SPHERE" : 1, "CYLINDER" : 2, "CONE" : 3, "TRIANGLEMESH" : 4, "CONVEXHULL" : 5}
        
        # check for special properties
        if obj.rbFlags & Blender.Object.RBFlags["ACTOR"]:
            actor = True
        if obj.rbFlags & Blender.Object.RBFlags["DYNAMIC"]:
            dynamic = True
            mass = obj.rbMass
        if obj.rbFlags & Object.RBFlags["BOUNDS"]:
            collisions = True
            if obj.rbShapeBoundType == HullTypes["BOX"]:
                collisionstype = "box"
            elif obj.rbShapeBoundType == HullTypes["SPHERE"]:
                collisionstype = "sphere"
            elif obj.rbShapeBoundType == HullTypes["CYLINDER"]:
                collisionstype = "cylinder"
            elif obj.rbShapeBoundType == HullTypes["CONE"]:
                collisionstype = "cone"
            elif obj.rbShapeBoundType == HullTypes["TRIANGLEMESH"]:
                collisionstype = "triangle"
            elif obj.rbShapeBoundType == HullTypes["CONVEXHULL"]:
                collisionstype = "hull"
            else:
                collisionstype = "hull"
        
        f.write("\tspecial_dynamic: %s\n" % dynamic)
        f.write("\tspecial_actor: %s\n" % actor)
        f.write("\tspecial_collisions: %s\n" % collisions)
        f.write("\tspecial_collisionstype: %s\n" % collisionstype)
        f.write("\tspecial_mass: %s\n" % mass)


if __name__ == '__main__':
	Window.FileSelector(export_properties, 'Export Custom Properties', sys.makename(ext='.txt'))
